@@ -1,12 +1,16 @@
 import logging
 
 import click
+from click import ClickException
 
-from yappa.cli_helpers import NaturalOrderGroup, create_function, \
-    create_function_version, \
-    create_gateway, get_missing_details, update_gateway
+from yappa.cli_helpers import (
+    NaturalOrderGroup, create_function,
+    create_function_version,
+    create_gateway, get_missing_details, update_gateway,
+)
 from yappa.config_generation import (
-    create_default_config, )
+    create_default_config,
+)
 from yappa.handlers.wsgi import DEFAULT_CONFIG_FILENAME, load_yaml, save_yaml
 from yappa.settings import DEFAULT_ACCESS_KEY_FILE, YANDEX_OAUTH_URL
 from yappa.yc import YC
@@ -90,9 +94,10 @@ def deploy(config_file):
     yc = YC.setup(config=config)
     function = create_function(yc, config)
     create_function_version(yc, config)
-    is_new = create_gateway(yc, config, function.id)
-    if not is_new:
-        update_gateway(yc, config)
+    if config["gw_config"]:
+        is_new = create_gateway(yc, config, function.id)
+        if not is_new:
+            update_gateway(yc, config)
 
 
 @cli.command()
@@ -103,6 +108,7 @@ def undeploy(config_file):
     deletes function, api-gateway and bucket
     """
     config = load_yaml(config_file)
+    raise ClickException("Oops! Looks like it's not yet implemented")
 
 
 if __name__ == '__main__':
